==> qt-mobility_1.1.0-0fn~fremantle4.tar.gz: qt-mobility-1.1.0/src/gallery/symbian/qmdegallerytyperesultset_p.h <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in 
** accordance with the Qt Commercial License Agreement provided with
** the Software or, alternatively, in accordance with the terms
** contained in a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QMDEGALLERYTYPERESULTSET_P_H
#define QMDEGALLERYTYPERESULTSET_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API. It exists purely as an
// implementation detail. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <qstringlist.h>

#include "qmdegalleryresultset_p.h"

QTM_BEGIN_NAMESPACE

class QGalleryTypeRequest;

class QMDEGalleryTypeResultSet : public QMDEGalleryResultSet
{
    Q_OBJECT
public:
    QMDEGalleryTypeResultSet(QMdeSession *session, QObject *parent = 0);
    ~QMDEGalleryTypeResultSet();

    void createQuery();

public: // from QGalleryResultSet

    virtual int itemCount() const;

    virtual QVariant itemId() const;
    virtual QUrl itemUrl() const;

    virtual QVariant metaData(int key) const;
    virtual bool setMetaData(int key, const QVariant &value);

    virtual bool fetch(int index);
    /* non pure virtual */
    virtual bool fetchNext();
    virtual bool fetchPrevious();
    virtual bool fetchFirst();
    virtual bool fetchLast();

private:

    QGalleryTypeRequest *m_request;
    QStringList m_propertyList;

};

QTM_END_NAMESPACE
#endif // QMDEGALLERYTYPERESULTSET_H

==> qt-mobility11_1.1.1-0fn~fremantle4.tar.gz: qt-mobility11-1.1.1/src/gallery/symbian/qmdegallerytyperesultset_p.h <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in 
** accordance with the Qt Commercial License Agreement provided with
** the Software or, alternatively, in accordance with the terms
** contained in a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QMDEGALLERYTYPERESULTSET_P_H
#define QMDEGALLERYTYPERESULTSET_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API. It exists purely as an
// implementation detail. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <qstringlist.h>

#include "qmdegalleryresultset_p.h"

#include <mdequery.h>

QTM_BEGIN_NAMESPACE

class QGalleryTypeRequest;

class QMDEGalleryTypeResultSet : public QGalleryResultSet, public MMdEQueryObserver
{
    Q_OBJECT
public:
    QMDEGalleryTypeResultSet(QMdeSession *session, QGalleryTypeRequest *request);
    ~QMDEGalleryTypeResultSet();

    int propertyKey(const QString &property) const;
    QGalleryProperty::Attributes propertyAttributes(int key) const;
    QVariant::Type propertyType(int key) const;

    int itemCount() const;

    bool isValid() const;

    QVariant itemId() const;
    QUrl itemUrl() const;
    QString itemType() const;

    QVariant metaData(int key) const;
    bool setMetaData(int key, const QVariant &value);

    int currentIndex() const;
    bool fetch(int index);

    void cancel();

    void HandleQueryNewResults(CMdEQuery &aQuery, TInt aFirstNewItemIndex, TInt aNewItemCount);
    void HandleQueryCompleted(CMdEQuery& aQuery, TInt aError);

private:
    const QString m_itemType;
    QScopedPointer<CMdEObjectQuery> m_query;
    int m_count;
    int m_itemCount;
    int m_currentIndex;
};

QTM_END_NAMESPACE
#endif // QMDEGALLERYTYPERESULTSET_H
